use strict;
use warnings;
package Rubric::CLI;
use base qw(App::Cmd);
our $VERSION = '0.143';

=head1 NAME

Rubric::CLI - the Rubric command line interface

=head1 VERSION

version 0.143

=cut

1;
